@@ -1,5 +1,5 @@
 /*
-  $Id: sample4.c,v 1.6 2004/08/07 10:50:03 rocky Exp $
+  $Id: sample4.c,v 1.7 2005/01/04 04:40:22 rocky Exp $
 
   Copyright (C) 2003, 2004 Rocky Bernstein <rocky@panix.com>
   
@@ -47,7 +47,7 @@ log_handler (cdio_log_level_t level, const char message[])
 static void
 print_analysis(cdio_iso_analysis_t cdio_iso_analysis, 
 	       cdio_fs_anal_t fs, int first_data, unsigned int num_audio, 
-	       track_t num_tracks, track_t first_track_num, CdIo *p_cdio)
+	       track_t num_tracks, track_t first_track_num, CdIo_t *p_cdio)
 {
   switch(CDIO_FSTYPE(fs)) {
   case CDIO_FS_AUDIO:
@@ -127,7 +127,7 @@ print_analysis(cdio_iso_analysis_t cdio_iso_analysis,
 int
 main(int argc, const char *argv[])
 {
-  CdIo *p_cdio;
+  CdIo_t *p_cdio;
   cdio_fs_anal_t fs=0;
   
   track_t num_tracks;
