@@ -1,5 +1,5 @@
 /*
-    $Id: cd_types.h,v 1.11 2004/06/23 09:28:02 rocky Exp $
+    $Id: cd_types.h,v 1.12 2005/01/27 03:10:06 rocky Exp $
 
     Copyright (C) 2003 Rocky Bernstein <rocky@panix.com>
     Copyright (C) 1996,1997,1998  Gerd Knorr <kraxel@bytesex.org>
@@ -136,7 +136,7 @@ typedef struct
  *  have at track track_num. Return information about the CD image
  *  is returned in iso_analysis and the return value.
  */
-cdio_fs_anal_t cdio_guess_cd_type(const CdIo *cdio, int start_session, 
+cdio_fs_anal_t cdio_guess_cd_type(const CdIo_t *cdio, int start_session, 
 				  track_t track_num, 
 				  /*out*/ cdio_iso_analysis_t *iso_analysis);
 
