@@ -1,5 +1,5 @@
 /* -*- c -*-
-    $Id: device.h,v 1.9 2005/01/29 20:54:20 rocky Exp $
+    $Id: device.h,v 1.23 2005/03/21 09:19:06 rocky Exp $
 
     Copyright (C) 2005 Rocky Bernstein <rocky@panix.com>
 
@@ -21,7 +21,7 @@
 /** \file device.h 
  *
  *  \brief The top-level header for driver- or device-related libcdio
- *          calls.  ("device" include CD-image reading devices).
+ *          calls.  ("device" includes CD-image reading devices).
  */
 #ifndef __CDIO_DEVICE_H__
 #define __CDIO_DEVICE_H__
@@ -30,6 +30,86 @@
 extern "C" {
 #endif /* __cplusplus */
 
+  /*! The type of an drive capability bit mask. See below for values*/
+  typedef uint32_t cdio_drive_read_cap_t;
+  typedef uint32_t cdio_drive_write_cap_t;
+  typedef uint32_t cdio_drive_misc_cap_t;
+  
+  /*!
+    \brief Drive types returned by cdio_get_drive_cap()
+    
+    NOTE: Setting a bit here means the presence of a capability.
+  */ 
+
+#define CDIO_DRIVE_CAP_ERROR          0x40000 /**< Error */
+#define CDIO_DRIVE_CAP_UNKNOWN        0x80000 /**< Dunno. It can be on if we
+					        have only partial information 
+                                                or are not completely certain
+                                              */
+
+#define CDIO_DRIVE_CAP_MISC_CLOSE_TRAY     0x00001 /**< caddy systems can't 
+                                                   close... */
+#define CDIO_DRIVE_CAP_MISC_EJECT          0x00002 /**< but can eject.  */
+#define CDIO_DRIVE_CAP_MISC_LOCK	   0x00004 /**< disable manual eject */
+#define CDIO_DRIVE_CAP_MISC_SELECT_SPEED   0x00008 /**< programmable speed */
+#define CDIO_DRIVE_CAP_MISC_SELECT_DISC    0x00010 /**< select disc from 
+                                                      juke-box */
+#define CDIO_DRIVE_CAP_MISC_MULTI_SESSION  0x00020 /**< read sessions>1 */
+#define CDIO_DRIVE_CAP_MISC_MEDIA_CHANGED  0x00080 /**< media changed */
+#define CDIO_DRIVE_CAP_MISC_RESET          0x00100 /**< hard reset device */
+#define CDIO_DRIVE_CAP_MISC_FILE           0x20000 /**< drive is really a file,
+                                                      i.e a CD file image */
+
+  /*! Reading masks.. */
+#define CDIO_DRIVE_CAP_READ_AUDIO       0x00001 /**< drive can play CD audio */
+#define CDIO_DRIVE_CAP_READ_CD_DA       0x00002 /**< drive can read CD-DA */
+#define CDIO_DRIVE_CAP_READ_CD_G        0x00004 /**< drive can read CD+G  */
+#define CDIO_DRIVE_CAP_READ_CD_R        0x00008 /**< drive can read CD-R  */
+#define CDIO_DRIVE_CAP_READ_CD_RW       0x00010 /**< drive can read CD-RW */
+#define CDIO_DRIVE_CAP_READ_DVD_R       0x00020 /**< drive can read DVD-R */
+#define CDIO_DRIVE_CAP_READ_DVD_PR      0x00040 /**< drive can read DVD+R */
+#define CDIO_DRIVE_CAP_READ_DVD_RAM     0x00080 /**< drive can read DVD-RAM */
+#define CDIO_DRIVE_CAP_READ_DVD_ROM     0x00100 /**< drive can read DVD-ROM */
+#define CDIO_DRIVE_CAP_READ_DVD_RW      0x00200 /**< drive can read DVD-RW  */
+#define CDIO_DRIVE_CAP_READ_DVD_RPW     0x00400 /**< drive can read DVD+RW  */
+#define CDIO_DRIVE_CAP_READ_C2_ERRS     0x00800 /**< has C2 error correction */
+#define CDIO_DRIVE_CAP_READ_MODE2_FORM1 0x01000 /**< can read mode 2 form 1 */
+#define CDIO_DRIVE_CAP_READ_MODE2_FORM2 0x02000 /**< can read mode 2 form 2 */
+#define CDIO_DRIVE_CAP_READ_MCN         0x04000 /**< can read MCN      */
+#define CDIO_DRIVE_CAP_READ_ISRC        0x08000 /**< can read ISRC     */
+
+  /*! Writing masks.. */
+#define CDIO_DRIVE_CAP_WRITE_CD_R       0x00001 /**< drive can write CD-R */
+#define CDIO_DRIVE_CAP_WRITE_CD_RW      0x00002 /**< drive can write CD-R */
+#define CDIO_DRIVE_CAP_WRITE_DVD_R      0x00004 /**< drive can write DVD-R */
+#define CDIO_DRIVE_CAP_WRITE_DVD_PR     0x00008 /**< drive can write DVD+R */
+#define CDIO_DRIVE_CAP_WRITE_DVD_RAM    0x00010 /**< drive can write DVD-RAM */
+#define CDIO_DRIVE_CAP_WRITE_DVD_RW     0x00020 /**< drive can write DVD-RW */
+#define CDIO_DRIVE_CAP_WRITE_DVD_RPW    0x00040 /**< drive can write DVD+RW */
+#define CDIO_DRIVE_CAP_WRITE_MT_RAINIER 0x00080 /**< Mount Rainier           */
+#define CDIO_DRIVE_CAP_WRITE_BURN_PROOF 0x00100 /**< burn proof */
+
+/**< Masks derived from above... */
+#define CDIO_DRIVE_CAP_WRITE_CD (                \
+    CDIO_DRIVE_CAP_WRITE_CD_R                    \
+    | CDIO_DRIVE_CAP_WRITE_CD_RW                 \
+    ) 
+/**< Has some sort of CD writer ability */
+
+/**< Masks derived from above... */
+#define CDIO_DRIVE_CAP_WRITE_DVD (               \
+    | CDIO_DRIVE_CAP_WRITE_DVD_R                 \
+    | CDIO_DRIVE_CAP_WRITE_DVD_PR                \
+    | CDIO_DRIVE_CAP_WRITE_DVD_RAM               \
+    | CDIO_DRIVE_CAP_WRITE_DVD_RW                \
+    | CDIO_DRIVE_CAP_WRITE_DVD_RPW               \
+    ) 
+/**< Has some sort of DVD writer ability */
+
+#define CDIO_DRIVE_CAP_WRITE \
+   (CDIO_DRIVE_CAP_WRITE_CD | CDIO_DRIVE_CAP_WRITE_DVD)
+/**< Has some sort of DVD or CD writing ability */
+
 /*! Size of fields returned by an INQUIRY command */
 #define CDIO_MMC_HW_VENDOR_LEN    8 /**< length of vendor field */
 #define CDIO_MMC_HW_MODEL_LEN    16 /**< length of model field */
@@ -114,27 +194,46 @@ extern "C" {
      integer.  C seems to tolerate this.
   */
   typedef enum  {
-    DRIVER_OP_UNINIT = -3,     /**< returned when a particular driver
-				   hasn't been initialized or a null
-				   CdIo_t pointer has been passed.
-				*/
-    DRIVER_OP_UNSUPPORTED = -2, /**< returned when a particular driver
-				   doesn't support a particular operation.
-				   For example an image driver which doesn't
-				   really "eject" a CD.
-				*/
-    DRIVER_OP_ERROR = -1,       /**< operation returned an error */
-    DRIVER_OP_SUCCESS = 0,      /**< in cases where an int is returned,
-				     like cdio_set_speed, more the negative
-				     return codes are for errors and the 
-				     positive ones for success. */
+    DRIVER_OP_SUCCESS = 0,       /**< in cases where an int is returned,
+				    like cdio_set_speed, more the negative
+				    return codes are for errors and the 
+				    positive ones for success. */
+    DRIVER_OP_ERROR = -1,        /**< operation returned an error */
+    DRIVER_OP_UNSUPPORTED = -2,  /**< returned when a particular driver
+				    doesn't support a particular operation.
+				    For example an image driver which doesn't
+				    really "eject" a CD.
+				 */
+    DRIVER_OP_UNINIT = -3,       /**< returned when a particular driver
+				    hasn't been initialized or a null
+				    pointer has been passed.
+				 */
+    DRIVER_OP_NOT_PERMITTED = -4, /**< Operation not permitted.
+				    For example might be a permission
+				    problem.
+				 */
+    DRIVER_OP_BAD_PARAMETER = -5, /**< Bad parameter passed  */
+    DRIVER_OP_BAD_POINTER =   -6, /**< Bad pointer to memory area  */
+    DRIVER_OP_NO_DRIVER  =    -7, /**< Operaton called on a driver
+				     not available on this OS  */
   } driver_return_code_t;
 
+  /*!
+    Close media tray in CD drive if there is a routine to do so. 
+    
+    @param psz_drive the name of CD-ROM to be closed.
+    @param p_driver_id is the driver to be used or that got used if
+    it was DRIVER_UNKNOWN or DRIVER_DEVICE; If this is NULL, we won't
+    report back the driver used.
+  */
+  driver_return_code_t cdio_close_tray (const char *psz_drive, 
+					/*in/out*/ driver_id_t *p_driver_id);
+
   /*!
     Eject media in CD drive if there is a routine to do so. 
 
     @param p_cdio the CD object to be acted upon.
-    If the CD is ejected *p_cdio is freed and p_cdio set to NULL.
+    If the CD is ejected *p_cdio is free'd and p_cdio set to NULL.
   */
   driver_return_code_t cdio_eject_media (CdIo_t **p_cdio);
 
@@ -165,6 +264,15 @@ extern "C" {
   */
   char * cdio_get_default_device (const CdIo_t *p_cdio);
 
+  /*!
+    Return a string containing the default CD device if none is specified.
+    if p_driver_id is DRIVER_UNKNOWN or DRIVER_DEVICE
+    then find a suitable one set the default device for that.
+    
+    NULL is returned if we couldn't get a default device.
+  */
+  char * cdio_get_default_device_driver (/*in/out*/ driver_id_t *p_driver_id);
+
   /*! Return an array of device names. If you want a specific
     devices for a driver, give that device. If you want hardware
     devices, give DRIVER_DEVICE and if you want all possible devices,
@@ -195,7 +303,7 @@ extern "C" {
     after dereferencing the the value is NULL. This also means nothing
     was found.
   */
-  char ** cdio_get_devices_with_cap (char* ppsz_search_devices[],
+  char ** cdio_get_devices_with_cap (/*in*/ char *ppsz_search_devices[],
 				     cdio_fs_anal_t capabilities, bool b_any);
 
   /*!
@@ -204,7 +312,7 @@ extern "C" {
     and then *open* it afterwards. Giving the driver back facilitates this,
     and speeds things up for libcdio as well.
   */
-  char ** cdio_get_devices_with_cap_ret (/*out*/ char* ppsz_search_devices[],
+  char ** cdio_get_devices_with_cap_ret (/*in*/ char* ppsz_search_devices[],
 					 cdio_fs_anal_t capabilities, 
 					 bool b_any,
 					 /*out*/ driver_id_t *p_driver_id);
@@ -274,16 +382,25 @@ extern "C" {
 			 /* out*/ cdio_hwinfo_t *p_hw_info );
 
 
-  /*!
-    Get the drive speed. 
+  /*! Get the LSN of the first track of the last session of
+    on the CD.
 
-    @return the drive speed if greater than 0. DRIVER_OP_ERROR if we
-    had an error, DRIVER_OP_UNSUPPORTED if this is not implemented for
-    the current driver.
-    
-    @see cdio_set_speed
+    @param p_cdio the CD object to be acted upon.
+    @param i_last_session pointer to the session number to be returned.
   */
-  int cdio_get_speed ( const CdIo_t *p_cdio, int i_speed );
+  driver_return_code_t cdio_get_last_session (CdIo_t *p_cdio,
+					      /*out*/ lsn_t *i_last_session);
+
+  /*! 
+      Find out if media has changed since the last call.
+      @param p_cdio the CD object to be acted upon.
+      @return 1 if media has changed since last call, 0 if not. Error
+      return codes are the same as driver_return_code_t
+   */
+  int cdio_get_media_changed(CdIo_t *p_cdio);
+
+  /*! True if CD-ROM understand ATAPI commands. */
+  bool_3way_t cdio_have_atapi (CdIo_t *p_cdio);
 
   /*! True if AIX driver is available. */
   bool cdio_have_aix    (void);
@@ -318,7 +435,7 @@ extern "C" {
   /*! Like cdio_have_xxx but uses an enumeration instead. */
   bool cdio_have_driver (driver_id_t driver_id);
   
-  /*!
+  /*
     Free any resources associated with p_cdio. Call this when done using p_cdio
     and using CD reading/control operations.
 
@@ -392,10 +509,9 @@ extern "C" {
 
   char **cdio_get_devices_bincue(void);
 
-  /*! Return a string containing the default CUE file that would
-      be used when none is specified.
-
-     NULL is returned on error or there is no device.
+  /*! @return string containing the default CUE file that would be
+      used when none is specified. NULL is returned on error or there
+      is no device.
    */
   char * cdio_get_default_device_cdrdao(void);
 
@@ -763,8 +879,6 @@ extern "C" {
 
   /*!
     Set the drive speed. 
-
-    @see cdio_get_speed
   */
   driver_return_code_t cdio_set_speed ( const CdIo_t *p_cdio, int i_speed );
 
@@ -797,4 +911,4 @@ extern "C" {
 }
 #endif /* __cplusplus */
 
-#endif /* __CDIO_TRACK_H__ */
+#endif /* __CDIO_DEVICE_H__ */
