@@ -1,5 +1,5 @@
 /*
-    $Id: cdio_private.h,v 1.11 2005/01/27 03:10:06 rocky Exp $
+    $Id: cdio_private.h,v 1.29 2005/03/23 11:26:49 rocky Exp $
 
     Copyright (C) 2003, 2004, 2005 Rocky Bernstein <rocky@panix.com>
 
@@ -29,8 +29,9 @@
 #endif
 
 #include <cdio/cdio.h>
+#include <cdio/audio.h>
 #include <cdio/cdtext.h>
-#include "scsi_mmc_private.h"
+#include "mmc_private.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -54,10 +55,79 @@ extern "C" {
   typedef struct {
     
     /*!
-      Eject media in CD drive. If successful, as a side effect we 
-      also free obj. Return 0 if success and 1 for failure.
+      Get volume of an audio CD.
+      
+      @param p_env the CD object to be acted upon.
+      
     */
-    int (*eject_media) (void *p_env);
+    driver_return_code_t (*audio_get_volume) 
+	 (void *p_env,  /*out*/ cdio_audio_volume_t *p_volume);
+
+    /*!
+      Pause playing CD through analog output
+      
+      @param p_env the CD object to be acted upon.
+    */
+    driver_return_code_t (*audio_pause) (void *p_env);
+    
+    /*!
+      Playing CD through analog output
+      
+      @param p_env the CD object to be acted upon.
+    */
+    driver_return_code_t (*audio_play_msf) ( void *p_env, 
+					     msf_t *p_start_msf,
+					     msf_t *p_end_msf );
+
+    /*!
+      Playing CD through analog output
+      
+      @param p_env the CD object to be acted upon.
+    */
+    driver_return_code_t (*audio_play_track_index) 
+	 ( void *p_env, cdio_track_index_t *p_track_index );
+
+    /*!
+      Get subchannel information.
+      
+      @param p_env the CD object to be acted upon.
+    */
+    driver_return_code_t (*audio_read_subchannel) 
+	 ( void *p_env, cdio_subchannel_t *subchannel );
+
+    /*!
+      Resume playing an audio CD.
+      
+      @param p_env the CD object to be acted upon.
+      
+    */
+    driver_return_code_t (*audio_resume) ( void *p_env );
+    
+    /*!
+      Set volume of an audio CD.
+      
+      @param p_env the CD object to be acted upon.
+      
+    */
+    driver_return_code_t (*audio_set_volume) 
+	 ( void *p_env,  cdio_audio_volume_t *p_volume );
+
+    /*!
+      Stop playing an audio CD.
+      
+      @param p_env the CD object to be acted upon.
+      
+    */
+    driver_return_code_t (*audio_stop) ( void *p_env );
+    
+    /*!
+      Eject media in CD drive. If successful, as a side effect we 
+      also free p_env. 
+
+      @param p_env the CD object to be acted upon.
+      If the CD is ejected *p_env is freed and p_env set to NULL.
+    */
+    driver_return_code_t (*eject_media) ( void *p_env );
     
     /*!
       Release and free resources associated with cd. 
@@ -73,7 +143,7 @@ extern "C" {
       Get the block size for subsequest read requests, via a SCSI MMC 
       MODE_SENSE 6 command.
     */
-    int (*get_blocksize) (void *p_env);
+    int (*get_blocksize) ( void *p_env );
     
     /*! 
       Get cdtext information for a CdIo object.
@@ -85,7 +155,7 @@ extern "C" {
       If i_track is 0 or CDIO_CDROM_LEADOUT_TRACK the track returned
       is the information assocated with the CD. 
     */
-    cdtext_t * (*get_cdtext) (void *p_env, track_t i_track);
+    cdtext_t * (*get_cdtext) ( void *p_env, track_t i_track );
     
     /*!
       Return an array of device names. if CdIo is NULL (we haven't
@@ -94,23 +164,30 @@ extern "C" {
       
       NULL is returned if we couldn't return a list of devices.
     */
-    char ** (*get_devices) (void);
+    char ** (*get_devices) ( void );
     
     /*!
-      Return a string containing the default CD device if none is specified.
+      Get the default CD device.
+
+      @return a string containing the default CD device or NULL is
+      if we couldn't get a default device.
+
+      In some situations of drivers or OS's we can't find a CD device if
+      there is no media in it and it is possible for this routine to return
+      NULL even though there may be a hardware CD-ROM.
     */
-    char * (*get_default_device)(void);
+    char * (*get_default_device) ( void );
     
     /*!
       Return the size of the CD in logical block address (LBA) units.
       @return the lsn. On error 0 or CDIO_INVALD_LSN.
     */
-    lsn_t (*get_disc_last_lsn) (void *p_env);
+    lsn_t (*get_disc_last_lsn) ( void *p_env );
 
     /*! 
       Get disc mode associated with cd_obj.
     */
-    discmode_t (*get_discmode) (void *p_env);
+    discmode_t (*get_discmode) ( void *p_env );
 
     /*!
       Return the what kind of device we've got.
@@ -125,38 +202,55 @@ extern "C" {
       Return the number of of the first track. 
       CDIO_INVALID_TRACK is returned on error.
     */
-    track_t (*get_first_track_num) (void *p_env);
+    track_t (*get_first_track_num) ( void *p_env );
     
     /*! 
       Get the CD-ROM hardware info via a SCSI MMC INQUIRY command.
       False is returned if we had an error getting the information.
     */
-    bool (*get_hwinfo) ( const CdIo_t *p_cdio, 
-			 /* out*/ cdio_hwinfo_t *p_hw_info );
+    bool (*get_hwinfo) 
+	 ( const CdIo_t *p_cdio, /* out*/ cdio_hwinfo_t *p_hw_info );
+
+    /*! Get the LSN of the first track of the last session of
+      on the CD.
+	   
+       @param p_cdio the CD object to be acted upon.
+       @param i_last_session pointer to the session number to be returned.
+    */
+    driver_return_code_t (*get_last_session)
+	 ( void *p_env, /*out*/ lsn_t *i_last_session );
+
+    /*! 
+      Find out if media has changed since the last call.
+      @param p_env the CD object to be acted upon.
+      @return 1 if media has changed since last call, 0 if not. Error
+      return codes are the same as driver_return_code_t
+    */
+    int (*get_media_changed) ( const void *p_env );
 
     /*!  
       Return the media catalog number MCN from the CD or NULL if
       there is none or we don't have the ability to get it.
     */
-    char * (*get_mcn) (const void *p_env);
+    char * (*get_mcn) ( const void *p_env );
 
     /*! 
       Return the number of tracks in the current medium.
       CDIO_INVALID_TRACK is returned on error.
     */
-    track_t (*get_num_tracks) (void *p_env);
+    track_t (*get_num_tracks) ( void *p_env );
     
     /*! Return number of channels in track: 2 or 4; -2 if not
       implemented or -1 for error.
       Not meaningful if track is not an audio track.
     */
-    int (*get_track_channels) (const void *p_env, track_t i_track);
+    int (*get_track_channels) ( const void *p_env, track_t i_track );
   
     /*! Return 0 if track is copy protected, 1 if not, or -1 for error
       or -2 if not implimented (yet). Is this meaningful if not an
       audio track?
     */
-    track_flag_t (*get_track_copy_permit) (void *p_env, track_t i_track);
+    track_flag_t (*get_track_copy_permit) ( void *p_env, track_t i_track );
   
     /*!  
       Return the starting LBA for track number
@@ -165,18 +259,12 @@ extern "C" {
       using track_num LEADOUT_TRACK or the total tracks+1.
       CDIO_INVALID_LBA is returned on error.
     */
-    lba_t (*get_track_lba) (void *p_env, track_t i_track);
+    lba_t (*get_track_lba) ( void *p_env, track_t i_track );
     
     /*!  
       Get format of track. 
     */
-    track_format_t (*get_track_format) (void *p_env, track_t i_track);
-    
-    /*!
-      Set the drive speed. -1 is returned if we had an error.
-      -2 is returned if this is not implemented for the current driver.
-    */
-    int (*get_speed) (void *p_env);
+    track_format_t (*get_track_format) ( void *p_env, track_t i_track );
     
     /*!
       Return true if we have XA data (green, mode2 form1) or
@@ -186,7 +274,7 @@ extern "C" {
       
       FIXME: there's gotta be a better design for this and get_track_format?
     */
-    bool (*get_track_green) (void *p_env, track_t i_track);
+    bool (*get_track_green) ( void *p_env, track_t i_track );
     
     /*!  
       Return the starting MSF (minutes/secs/frames) for track number
@@ -195,65 +283,88 @@ extern "C" {
       using i_track LEADOUT_TRACK or the total tracks+1.
       False is returned on error.
     */
-    bool (*get_track_msf) (void *p_env, track_t i_track, msf_t *p_msf);
+    bool (*get_track_msf) ( void *p_env, track_t i_track, msf_t *p_msf );
     
     /*! Return 1 if track has pre-emphasis, 0 if not, or -1 for error
       or -2 if not implimented (yet). Is this meaningful if not an
       audio track?
     */
-    track_flag_t (*get_track_preemphasis) (const void  *p_env, 
-					   track_t i_track);
+    track_flag_t (*get_track_preemphasis) 
+	 ( const void  *p_env, track_t i_track );
   
     /*!
       lseek - reposition read/write file offset
       Returns (off_t) -1 on error. 
       Similar to libc's lseek()
     */
-    off_t (*lseek) (void *p_env, off_t offset, int whence);
+    off_t (*lseek) ( void *p_env, off_t offset, int whence );
     
     /*!
       Reads into buf the next size bytes.
       Returns -1 on error. 
       Similar to libc's read()
     */
-    ssize_t (*read) (void *p_env, void *p_buf, size_t size);
+    ssize_t (*read) ( void *p_env, void *p_buf, size_t i_size );
     
     /*!
       Reads a single mode2 sector from cd device into buf starting
       from lsn. Returns 0 if no error. 
     */
-    int (*read_audio_sectors) (void *p_env, void *p_buf, lsn_t lsn,
-			       unsigned int i_blocks);
+    int (*read_audio_sectors) ( void *p_env, void *p_buf, lsn_t i_lsn,
+				unsigned int i_blocks );
+    
+    /*!
+      Read a data sector
+      
+      @param p_env environment to read from
+
+      @param p_buf place to read data into.  The caller should make sure
+      this location can store at least CDIO_CD_FRAMESIZE, 
+      M2RAW_SECTOR_SIZE, or M2F2_SECTOR_SIZE depending
+      on the kind of sector getting read. If you don't 
+      know whether you have a Mode 1/2, Form 1/ Form 2/Formless
+      sector best to reserve space for the maximum, 
+      M2RAW_SECTOR_SIZE.
+
+      @param i_lsn sector to read
+      @param i_blocksize size of block. Should be either CDIO_CD_FRAMESIZE, 
+      M2RAW_SECTOR_SIZE, or M2F2_SECTOR_SIZE. See comment above under p_buf.
+    */
+    driver_return_code_t (*read_data_sectors) 
+	 ( void *p_env, void *p_buf, lsn_t i_lsn, uint16_t i_blocksize,
+	   uint32_t i_blocks );
     
     /*!
       Reads a single mode2 sector from cd device into buf starting
       from lsn. Returns 0 if no error. 
     */
-    int (*read_mode2_sector) (void *p_env, void *p_buf, lsn_t lsn, 
-			      bool b_mode2_form2);
+    int (*read_mode2_sector) 
+	 ( void *p_env, void *p_buf, lsn_t i_lsn, bool b_mode2_form2 );
     
     /*!
       Reads i_blocks of mode2 sectors from cd device into data starting
       from lsn.
       Returns 0 if no error. 
     */
-    int (*read_mode2_sectors) (void *p_env, void *p_buf, lsn_t lsn, 
-			       bool b_mode2_form2, unsigned int i_blocks);
+    int (*read_mode2_sectors) 
+	 ( void *p_env, void *p_buf, lsn_t i_lsn, bool b_mode2_form2, 
+	   unsigned int i_blocks );
     
     /*!
       Reads a single mode1 sector from cd device into buf starting
       from lsn. Returns 0 if no error. 
     */
-    int (*read_mode1_sector) (void *p_env, void *p_buf, lsn_t lsn, 
-			      bool mode1_form2);
+    int (*read_mode1_sector) 
+	 ( void *p_env, void *p_buf, lsn_t i_lsn, bool mode1_form2 );
     
     /*!
       Reads i_blocks of mode1 sectors from cd device into data starting
       from lsn.
       Returns 0 if no error. 
     */
-    int (*read_mode1_sectors) (void *p_env, void *p_buf, lsn_t lsn, 
-			       bool mode1_form2, unsigned int i_blocks);
+    int (*read_mode1_sectors) 
+	 ( void *p_env, void *p_buf, lsn_t i_lsn, bool mode1_form2, 
+	   unsigned int i_blocks );
     
     bool (*read_toc) ( void *p_env ) ;
 
@@ -273,20 +384,18 @@ extern "C" {
       
       Returns 0 if command completed successfully.
     */
-    scsi_mmc_run_cmd_fn_t run_scsi_mmc_cmd;
+    mmc_run_cmd_fn_t run_mmc_cmd;
 
     /*!
       Set the arg "key" with "value" in the source device.
     */
-    int (*set_arg) (void *p_env, const char key[], const char value[]);
+    int (*set_arg) ( void *p_env, const char key[], const char value[] );
     
     /*!
       Set the blocksize for subsequent reads. 
-      
-      @return 0 if everything went okay, -1 if we had an error. is -2
-      returned if this is not implemented for the current driver.
     */
-    int (*set_blocksize) ( void *p_env, int i_blocksize );
+    driver_return_code_t (*set_blocksize) ( void *p_env, 
+					    uint16_t i_blocksize );
 
     /*!
       Set the drive speed. 
@@ -328,12 +437,13 @@ extern "C" {
     const char  *name;
     const char  *describe;
     bool (*have_driver) (void); 
-    CdIo *(*driver_open) (const char *psz_source_name); 
-    CdIo *(*driver_open_am) (const char *psz_source_name, 
+    CdIo_t *(*driver_open) (const char *psz_source_name); 
+    CdIo_t *(*driver_open_am) (const char *psz_source_name, 
 			     const char *psz_access_mode); 
     char *(*get_default_device) (void); 
     bool (*is_device) (const char *psz_source_name);
     char **(*get_devices) (void);
+    driver_return_code_t (*close_tray) (const char *psz_device);
   } CdIo_driver_t;
 
   /* The below array gives of the drivers that are currently available for 
@@ -353,9 +463,17 @@ extern "C" {
     Add/allocate a drive to the end of drives. 
     Use cdio_free_device_list() to free this device_list.
   */
-  void cdio_add_device_list(char **device_list[], const char *drive, 
+  void cdio_add_device_list(char **device_list[], const char *psz_drive,
 			    unsigned int *i_drives);
 
+  driver_return_code_t close_tray_bsdi    (const char *psz_drive);
+  driver_return_code_t close_tray_freebsd (const char *psz_drive);
+  driver_return_code_t close_tray_linux   (const char *psz_drive);
+  driver_return_code_t close_tray_osx     (const char *psz_drive);
+  driver_return_code_t close_tray_solaris (const char *psz_drive);
+  driver_return_code_t close_tray_win32   (const char *psz_drive);
+
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
