@@ -1,5 +1,5 @@
 /*
-    $Id: cd-info.c,v 1.142 2005/07/03 23:14:23 rocky Exp $
+    $Id: cd-info.c,v 1.144 2005/09/18 20:34:02 rocky Exp $
 
     Copyright (C) 2003, 2004, 2005 Rocky Bernstein <rocky@panix.com>
     Copyright (C) 1996, 1997, 1998  Gerd Knorr <kraxel@bytesex.org>
@@ -115,7 +115,7 @@ char *temp_str;
 static bool
 parse_options (int argc, const char *argv[])
 {
-  char opt; /* used for argument parsing */
+  int opt; /* used for argument parsing */
   char *psz_my_source;
   
   struct poptOption optionsTable[] = {
@@ -443,9 +443,7 @@ print_cddb_info(CdIo_t *p_cdio, track_t i_tracks, track_t i_first_track)
   
     cddb_disc_destroy(p_cddb_disc);
     cddb_destroy(p_conn);
-#if LIBCDDB_VERSION_NUM >= 1
     libcddb_shutdown();
-#endif
   }
 }
 #endif
