@@ -1,5 +1,5 @@
 /*
-    $Id: iso-info.c,v 1.20 2005/01/22 22:21:36 rocky Exp $
+    $Id: iso-info.c,v 1.30 2005/03/18 12:56:00 rocky Exp $
 
     Copyright (C) 2004, 2005 Rocky Bernstein <rocky@panix.com>
 
@@ -65,6 +65,8 @@ struct arguments
   int            silent;
   int            no_header;
   int            no_joliet;
+  int            no_xa;
+  int            no_rock_ridge;
   int            print_iso9660;
   int            print_iso9660_short;
 } opts;
@@ -104,9 +106,15 @@ parse_options (int argc, const char *argv[])
 
 #ifdef HAVE_JOLIET    
     {"no-joliet", '\0', POPT_ARG_NONE, &opts.no_joliet, 
-     0, "Don't use Joliet extensions"},
+     0, "Don't use Joliet-extension information"},
 #endif /*HAVE_JOLIET*/
     
+    {"no-rock-ridge", '\0', POPT_ARG_NONE, &opts.no_rock_ridge, 
+     0, "Don't use Rock-Ridge-extension information"},
+
+    {"no-xa", '\0', POPT_ARG_NONE, &opts.no_xa, 
+     0, "Don't use XA-extension information"},
+
     {"quiet",       'q', POPT_ARG_NONE, &opts.silent, 0,
      "Don't produce warning output" },
     
@@ -119,12 +127,16 @@ parse_options (int argc, const char *argv[])
   program_name = strrchr(argv[0],'/');
   program_name = program_name ? strdup(program_name+1) : strdup(argv[0]);
 
-  while ((opt = poptGetNextOpt (optCon)) != -1) {
-    switch (opt) {
-    default:
-      poptFreeContext(optCon);
-      return false;
-    }
+  while ((opt = poptGetNextOpt (optCon)) >= 0) {
+    ;
+  }
+  if (opt < -1) {
+    /* an error occurred during option processing */
+    report(stderr, "%s: %s\n",
+	    poptBadOption(optCon, POPT_BADOPTION_NOALIAS),
+	    poptStrerror(opt));
+    free(program_name);
+    exit (EXIT_FAILURE);
   }
   {
     const char *remaining_arg = poptGetArg(optCon);
@@ -133,6 +145,7 @@ parse_options (int argc, const char *argv[])
 	report( stderr, "%s: Source specified in previously %s and %s\n", 
 		    program_name, source_name, remaining_arg );
 	poptFreeContext(optCon);
+	free(program_name);
 	exit (EXIT_FAILURE);
       }
       source_name = strdup(remaining_arg);
@@ -145,8 +158,6 @@ parse_options (int argc, const char *argv[])
 
 /* CDIO logging routines */
 
-static cdio_log_handler_t gl_default_cdio_log_handler = NULL;
-
 static void 
 _log_handler (cdio_log_level_t level, const char message[])
 {
@@ -185,48 +196,42 @@ print_iso9660_recurse (iso9660_t *p_iso, const char pathname[])
   
   _CDIO_LIST_FOREACH (entnode, entlist)
     {
-      iso9660_stat_t *statbuf = _cdio_list_node_data (entnode);
-      char *iso_name = statbuf->filename;
+      iso9660_stat_t *p_statbuf = _cdio_list_node_data (entnode);
+      char *psz_iso_name = p_statbuf->filename;
       char _fullname[4096] = { 0, };
       char translated_name[MAX_ISONAME+1];
-#define DATESTR_SIZE 30
-      char date_str[DATESTR_SIZE];
 
-      iso9660_name_translate_ext(iso_name, translated_name, i_joliet_level);
+      if (yep != p_statbuf->rr.b3_rock || 1 == opts.no_rock_ridge) {
+	iso9660_name_translate_ext(psz_iso_name, translated_name, 
+				   i_joliet_level);
+	snprintf (_fullname, sizeof (_fullname), "%s%s", pathname, 
+		  translated_name);
+      } else {
+	snprintf (_fullname, sizeof (_fullname), "%s%s", pathname, 
+		  psz_iso_name);
+      }
       
-      snprintf (_fullname, sizeof (_fullname), "%s%s", pathname, 
-		iso_name);
-  
       strncat (_fullname, "/", sizeof (_fullname));
 
-      if (statbuf->type == _STAT_DIR
-          && strcmp (iso_name, ".") 
-          && strcmp (iso_name, ".."))
+      if (p_statbuf->type == _STAT_DIR
+          && strcmp (psz_iso_name, ".") 
+          && strcmp (psz_iso_name, ".."))
         _cdio_list_append (dirlist, strdup (_fullname));
 
       if (opts.print_iso9660) {
-	if (iso9660_ifs_is_xa(p_iso)) {
-	  printf ( "  %c %s %d %d [fn %.2d] [LSN %6lu] ",
-		   (statbuf->type == _STAT_DIR) ? 'd' : '-',
-		   iso9660_get_xa_attr_str (statbuf->xa.attributes),
-		   uint16_from_be (statbuf->xa.user_id),
-		   uint16_from_be (statbuf->xa.group_id),
-		   statbuf->xa.filenum,
-		   (long unsigned int) statbuf->lsn);
-	  
-	  if (uint16_from_be(statbuf->xa.attributes) & XA_ATTR_MODE2FORM2) {
-	    printf ("%9u (%9u)",
-		    (unsigned int) statbuf->secsize * M2F2_SECTOR_SIZE,
-		    (unsigned int) statbuf->size);
-	  } else {
-	    printf ("%9u", (unsigned int) statbuf->size);
-	  }
-	}
-	strftime(date_str, DATESTR_SIZE, "%b %d %Y %H:%M ", &statbuf->tm);
-	printf (" %s %s\n", date_str, translated_name);
+	print_fs_attrs(p_statbuf, 
+		       0 == opts.no_rock_ridge,
+		       iso9660_ifs_is_xa(p_iso) && 0 == opts.no_xa,
+		       psz_iso_name, translated_name);
       } else 
-	if ( strcmp (iso_name, ".") && strcmp (iso_name, ".."))
-	  printf("%s%s\n", pathname, translated_name);
+	if ( strcmp (psz_iso_name, ".") && strcmp (psz_iso_name, ".."))
+	  printf("%9u %s%s\n", (unsigned int) p_statbuf->size, pathname, 
+		 yep == p_statbuf->rr.b3_rock 
+		 ? psz_iso_name : translated_name);
+      if (p_statbuf->rr.i_symlink) {
+	free(p_statbuf->rr.psz_symlink);
+	p_statbuf->rr.i_symlink = 0;
+      }
     }
 
   _cdio_list_free (entlist, true);
@@ -263,7 +268,9 @@ init(void)
   /* Default option values. */
   opts.silent              = false;
   opts.no_header           = false;
-  opts.no_joliet           = false;
+  opts.no_joliet           = 0;
+  opts.no_rock_ridge       = 0;
+  opts.no_xa               = 0;
   opts.debug_level         = 0;
   opts.print_iso9660       = 0;
   opts.print_iso9660_short = 0;
@@ -272,9 +279,9 @@ init(void)
 #define print_vd_info(title, fn)	  \
   if (fn(p_iso, &psz_str)) {		  \
     printf(title ": %s\n", psz_str);	  \
-    free(psz_str);			  \
-    psz_str = NULL;			  \
-  }
+  }					  \
+  free(psz_str);			  \
+  psz_str = NULL;			  
 
 /* ------------------------------------------------------------------------ */
 
@@ -290,7 +297,7 @@ main(int argc, const char *argv[])
   /* Parse our arguments; every option seen by `parse_opt' will
      be reflected in `arguments'. */
   parse_options(argc, argv);
-     
+  
   print_version(program_name, CDIO_VERSION, opts.no_header, opts.version_only);
 
   if (opts.debug_level == 3) {
