@@ -1,5 +1,5 @@
 #!/bin/sh
-#$Id: check_cue.sh.in,v 1.28 2005/04/11 02:36:36 rocky Exp $
+#$Id: check_cue.sh.in,v 1.29 2005/09/15 06:36:01 rocky Exp $
 # Tests to see that BIN/CUE and cdrdao TOC file iamge reading is correct
 # (via cd-info).
 
@@ -44,28 +44,32 @@ check_result $RC "cd-info TOC test $testnum" "${CD_INFO} $opts"
 fname=isofs-m1
 testnum='ISO 9660 mode1 CUE'
 if test -f  ${srcdir}/${fname}.bin ; then
-  opts="-q --no-device-info --no-disc-mode --cue-file ${srcdir}/${fname}.cue --iso9660"
-  test_cdinfo "$opts" ${fname}.dump ${srcdir}/${fname}.right
-  RC=$?
-  check_result $RC "cd-info Rock-Ridge CUE test $testnum" "${CD_INFO} $opts"
+  if test -n "1"; then 
+    opts="-q --no-device-info --no-disc-mode --cue-file ${srcdir}/${fname}.cue --iso9660"
+    test_cdinfo "$opts" ${fname}.dump ${srcdir}/${fname}.right
+    RC=$?
+    check_result $RC "cd-info Rock-Ridge CUE test $testnum" "${CD_INFO} $opts"
 
-  opts="-q --no-device-info --no-disc-mode --no-rock-ridge --cue-file ${srcdir}/${fname}.cue --iso9660"
-  test_cdinfo "$opts" ${fname}.dump ${srcdir}/${fname}-no-rr.right
-  RC=$?
-  check_result $RC "cd-info no Rock-Ridge CUE test $testnum" "${CD_INFO} $opts"
+    opts="-q --no-device-info --no-disc-mode --no-rock-ridge --cue-file ${srcdir}/${fname}.cue --iso9660"
+    test_cdinfo "$opts" ${fname}.dump ${srcdir}/${fname}-no-rr.right
+    RC=$?
+    check_result $RC "cd-info no Rock-Ridge CUE test $testnum" "${CD_INFO} $opts"
+  fi
 
 else 
   echo "Don't see CUE file ${srcdir}/${fname}.bin. Test $testnum skipped."
 fi
 
-testnum='ISO 9660 mode1 TOC'
-if test -f  ${srcdir}/${fname}.bin ; then
-  opts="-q --no-device-info --no-disc-mode --toc-file ${srcdir}/${fname}.toc --iso9660"
-  test_cdinfo "$opts" ${fname}.dump ${srcdir}/${fname}.right
-  RC=$?
-  check_result $RC "cd-info TOC test $testnum" "${CD_INFO} $opts"
-else 
-  echo "Don't see TOC file ${srcdir}/${fname}.bin. Test $testnum skipped."
+if test -n "1"; then 
+  testnum='ISO 9660 mode1 TOC'
+  if test -f  ${srcdir}/${fname}.bin ; then
+    opts="-q --no-device-info --no-disc-mode --toc-file ${srcdir}/${fname}.toc --iso9660"
+    test_cdinfo "$opts" ${fname}.dump ${srcdir}/${fname}.right
+    RC=$?
+    check_result $RC "cd-info TOC test $testnum" "${CD_INFO} $opts"
+  else 
+    echo "Don't see TOC file ${srcdir}/${fname}.bin. Test $testnum skipped."
+  fi
 fi
 
 fname=vcd_demo
