@@ -1,5 +1,5 @@
 #!/bin/sh
-#$Id: check_iso.sh.in,v 1.9 2005/03/05 23:51:40 rocky Exp $
+#$Id: check_iso.sh.in,v 1.10 2005/09/15 06:36:01 rocky Exp $
 
 if test -z $srcdir ; then
   srcdir=`pwd`
@@ -24,11 +24,13 @@ test_iso_read  "$opts" ${fname} ${srcdir}/../COPYING
 RC=$?
 check_result $RC 'iso-read basic test' "$ISO_READ $opts"
 
-fname=copying-rr
-opts="--quiet ${srcdir}/${fname}.iso --iso9660 "
-test_iso_info  "$opts" ${fname}.dump ${srcdir}/${fname}.right
-RC=$?
-check_result $RC 'iso-info Rock Ridge test' "$ISO_INFO $opts"
+if test -n "1"; then
+  fname=copying-rr
+  opts="--quiet ${srcdir}/${fname}.iso --iso9660 "
+  test_iso_info  "$opts" ${fname}.dump ${srcdir}/${fname}.right
+  RC=$?
+  check_result $RC 'iso-info Rock Ridge test' "$ISO_INFO $opts"
+fi
 
 if test -n "1" ; then
   BASE=`basename $0 .sh`
